@@ -1,4 +1,5 @@
 #!/usr/bin/python3
+import os
 import sys
 
 from lintian_brush.control import (
@@ -6,11 +7,14 @@ from lintian_brush.control import (
     ensure_minimum_debhelper_version,
     update_control,
     )
+from lintian_brush.debhelper import maximum_debhelper_compat_version
 from lintian_brush.rules import (
     dh_invoke_drop_with,
     update_rules,
     )
 
+compat_release = os.environ.get('COMPAT_RELEASE', 'sid')
+
 
 def bump_debhelper(control):
     control["Build-Depends"] = ensure_minimum_debhelper_version(
@@ -24,6 +28,9 @@ def drop_with_autoreconf(line, target):
     return dh_invoke_drop_with(line, b'autoreconf')
 
 
+if maximum_debhelper_compat_version(compat_release) < 10:
+    sys.exit(0)
+
 changed = update_rules(drop_with_autoreconf)
 if not changed:
     sys.exit(2)
